searchData={"items":[{"type":"module","title":"ReqBigQuery","doc":"`Req` plugin for [Google BigQuery](https://cloud.google.com/bigquery/docs/reference/rest).\n\nReqBigQuery makes it easy to make BigQuery queries. It uses `Goth` for authentication.\nQuery results are decoded into the `ReqBigQuery.Result` struct.\nThe struct implements the `Table.Reader` protocol and thus can be efficiently traversed by rows or columns.","ref":"ReqBigQuery.html"},{"type":"function","title":"ReqBigQuery.attach/2","doc":"Attaches to Req request.","ref":"ReqBigQuery.html#attach/2"},{"type":"function","title":"Request Options - ReqBigQuery.attach/2","doc":"* `:goth` - Required. The goth server name.\n\n  * `:project_id` - Required. The GCP project id.\n\n  * `:bigquery` - Required. The query to execute. It can be a plain sql string or\n    a `{query, params}` tuple, where `query` can contain `?` placeholders and `params`\n    is a list of corresponding values.\n\n  * `:default_dataset_id` - Optional. If set, the dataset to assume for any unqualified table\n    names in the query. If not set, all table names in the query string must be qualified in the\n    format 'datasetId.tableId'.\n\n  * `:max_results` - Optional. Number of rows to be returned by BigQuery in each request (paging).\n    The rows Stream can make multiple requests if `num_rows` returned is grather than `:max_results`.\n    Defaults to 10000.\n\n  * `:use_legacy_sql` - Optional. Specifies whether to use BigQuery's legacy SQL dialect for this query.\n    If set to false, the query will use BigQuery's GoogleSQL: https://cloud.google.com/bigquery/sql-reference/\n    The default value is false.\n\n  * `:timeout_ms` - Optional. How long to wait for the query to complete, in milliseconds,\n    before the request times out and returns. Note: The call is not guaranteed to wait for\n    the specified timeout. If the query takes longer to run than the timeout value, the call\n    returns without any results and with the 'jobComplete' flag set to false. The default\n    value is 10000 milliseconds (10 seconds).\n\n  * `:dry_run` - Optional. Specifies whether to run the given query in dry run mode.\n\nIf you want to set any of these options when attaching the plugin, pass them as the second argument.","ref":"ReqBigQuery.html#attach/2-request-options"},{"type":"function","title":"Examples - ReqBigQuery.attach/2","doc":"With plain query string:\n\n    iex> credentials = File.read!(\"credentials.json\") |> Jason.decode!()\n    iex> source = {:service_account, credentials, []}\n    iex> {:ok, _} = Goth.start_link(name: MyGoth, source: source, http_client: &Req.request/1)\n    iex> project_id = System.fetch_env!(\"PROJECT_ID\")\n    iex> query = \"\"\"\n    ...> SELECT title, SUM(views) AS views\n    ...>   FROM `bigquery-public-data.wikipedia.table_bands`\n    ...>  WHERE EXTRACT(YEAR FROM datehour) <= 2021\n    ...>  GROUP BY title\n    ...>  ORDER BY views DESC\n    ...>  LIMIT 10\n    ...> \"\"\"\n    iex> req = Req.new() |> ReqBigQuery.attach(goth: MyGoth, project_id: project_id)\n    iex> res = Req.post!(req, bigquery: query).body\n    iex> res\n    %ReqBigQuery.Result{\n      columns: [\"title\", \"views\"],\n      job_id: \"job_JDDZKquJWkY7x0LlDcmZ4nMQqshb\",\n      num_rows: 10,\n      total_bytes_processed: 18161868216,\n      rows: %Stream{}\n    }\n    iex> Enum.to_list(res.rows)\n    [\n        [\"The_Beatles\", 13758950],\n        [\"Queen_(band)\", 12019563],\n        [\"Pink_Floyd\", 9522503],\n        [\"AC/DC\", 8972364],\n        [\"Led_Zeppelin\", 8294994],\n        [\"Linkin_Park\", 8242802],\n        [\"The_Rolling_Stones\", 7825952],\n        [\"Red_Hot_Chili_Peppers\", 7302904],\n        [\"Fleetwood_Mac\", 7199563],\n        [\"Twenty_One_Pilots\", 6970692]\n    ]\n\nWith parameterized query:\n\n    iex> credentials = File.read!(\"credentials.json\") |> Jason.decode!()\n    iex> source = {:service_account, credentials, []}\n    iex> {:ok, _} = Goth.start_link(name: MyGoth, source: source, http_client: &Req.request/1)\n    iex> project_id = System.fetch_env!(\"PROJECT_ID\")\n    iex> query = \"\"\"\n    ...> SELECT EXTRACT(YEAR FROM datehour) AS year, SUM(views) AS views\n    ...>   FROM `bigquery-public-data.wikipedia.table_bands`\n    ...>  WHERE EXTRACT(YEAR FROM datehour) <= 2021\n    ...>    AND title = ?\n    ...>  GROUP BY 1\n    ...>  ORDER BY views DESC\n    ...> \"\"\"\n    iex> req = Req.new() |> ReqBigQuery.attach(goth: MyGoth, project_id: project_id)\n    iex> res = Req.post!(req, bigquery: {query, [\"Linkin_Park\"]}).body\n    %ReqBigQuery.Result{\n      columns: [\"year\", \"views\"],\n      job_id: \"job_GXiJvALNsTAoAOJ39Eg3Mw94XMUQ\",\n      num_rows: 7,\n      total_bytes_processed: 15686357820,\n      rows: %Stream{}\n    }\n    iex> Enum.to_list(res.rows)\n    [[2017, 2895889], [2016, 1173359], [2018, 1133770], [2020, 906538], [2015, 860899], [2019, 790747], [2021, 481600]]","ref":"ReqBigQuery.html#attach/2-examples"},{"type":"module","title":"ReqBigQuery.Result","doc":"Result struct returned from any successful query.\n\nIts fields are:\n\n  * `columns` - The column names;\n  * `rows` - The result set. A list of lists, each inner list corresponding to a\n    row, each element in the inner list corresponds to a column;\n  * `num_rows` - The number of fetched or affected rows;\n  * `total_bytes_processed` - The total number of bytes processed for the query;\n  * `job_id` - The ID of the Google BigQuery's executed job. Returns nil for dry runs.","ref":"ReqBigQuery.Result.html"},{"type":"type","title":"ReqBigQuery.Result.t/0","doc":"","ref":"ReqBigQuery.Result.html#t:t/0"},{"type":"extras","title":"ReqBigQuery","doc":"# ReqBigQuery\n\n[![Hex pm](http://img.shields.io/hexpm/v/req_bigquery.svg?style=flat)](https://hex.pm/packages/req_bigquery)\n\n[Req](https://github.com/wojtekmach/req) plugin for [Google BigQuery](https://cloud.google.com/bigquery/docs/reference/rest).\n\nReqBigQuery makes it easy to make BigQuery queries. It uses [Goth](https://github.com/peburrows/goth)\nfor authentication. Query results are decoded into the `ReqBigQuery.Result` struct.\nThe struct implements the `Table.Reader` protocol and thus can be efficiently traversed by rows or columns.","ref":"readme.html"},{"type":"extras","title":"Usage - ReqBigQuery","doc":"```elixir\nMix.install([\n  {:goth, \"~> 1.3.0\"},\n  {:req, \"~> 0.3.5\"},\n  {:req_bigquery, \"~> 0.1.1\"}\n])\n\n# We use Goth to authenticate to Google Cloud API.\n# See: https://hexdocs.pm/goth/1.3.0-rc.4/Goth.Token.html#fetch/1-source for more information.\ncredentials = File.read!(\"credentials.json\") |> Jason.decode!()\nsource = {:service_account, credentials, []}\n{:ok, _} = Goth.start_link(name: MyGoth, source: source, http_client: &Req.request/1)\n\nproject_id = System.fetch_env!(\"PROJECT_ID\")\n\n# With plain string query\nquery = \"\"\"\nSELECT title, SUM(views) AS views\n  FROM `bigquery-public-data.wikipedia.table_bands`\n WHERE EXTRACT(YEAR FROM datehour) <= 2021\n GROUP BY title\n ORDER BY views DESC\n LIMIT 10\n\"\"\"\n\nreq = Req.new() |> ReqBigQuery.attach(goth: MyGoth, project_id: project_id)\nres = Req.post!(req, bigquery: query).body\n#=>\n# %ReqBigQuery.Result{\n#   columns: [\"title\", \"views\"],\n#   job_id: \"job_JDDZKquJWkY7x0LlDcmZ4nMQqshb\",\n#   num_rows: 10,\n#   rows: %Stream{}\n# }\n\nEnum.to_list(res.rows)\n#=>\n# [\n#   [\"The_Beatles\", 13758950],\n#   [\"Queen_(band)\", 12019563],\n#   [\"Pink_Floyd\", 9522503],\n#   [\"AC/DC\", 8972364],\n#   [\"Led_Zeppelin\", 8294994],\n#   [\"Linkin_Park\", 8242802],\n#   [\"The_Rolling_Stones\", 7825952],\n#   [\"Red_Hot_Chili_Peppers\", 7302904],\n#   [\"Fleetwood_Mac\", 7199563],\n#   [\"Twenty_One_Pilots\", 6970692]\n# ]\n\n# With parameterized query\nquery = \"\"\"\nSELECT EXTRACT(YEAR FROM datehour) AS year, SUM(views) AS views\n  FROM `bigquery-public-data.wikipedia.table_bands`\n WHERE EXTRACT(YEAR FROM datehour) <= 2021\n   AND title = ?\n GROUP BY year\n ORDER BY views DESC\n\"\"\"\n\nreq = Req.new() |> ReqBigQuery.attach(goth: MyGoth, project_id: project_id)\nres = Req.post!(req, bigquery: {query, [\"Linkin_Park\"]}).body\n#=>\n# %ReqBigQuery.Result{\n#   columns: [\"year\", \"views\"],\n#   job_id: \"job_GXiJvALNsTAoAOJ39Eg3Mw94XMUQ\",\n#   num_rows: 7,\n#   rows: %Stream{}\n# }\n\nEnum.to_list(res.rows)\n#=> [[2017, 2895889], [2016, 1173359], [2018, 1133770], [2020, 906538], [2015, 860899], [2019, 790747], [2021, 481600]]\n```","ref":"readme.html#usage"},{"type":"extras","title":"License - ReqBigQuery","doc":"Copyright (C) 2022 Dashbit\n\n    Licensed under the Apache License, Version 2.0 (the \"License\");\n    you may not use this file except in compliance with the License.\n    You may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\n    Unless required by applicable law or agreed to in writing, software\n    distributed under the License is distributed on an \"AS IS\" BASIS,\n    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n    See the License for the specific language governing permissions and\n    limitations under the License.","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}